- {/* Video player using Video.js */}
+ {/* Video player using original Bunny.net iframe */}
-
+ frameBorder="0"
+ allowFullScreen
+ allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
+ onLoad={handleVideoPlay}
+ title={currentVideo.title}
+ />
{/* Video info */}
diff --git a/server/storage.ts b/server/storage.ts
index 477fa0d..ae66014 100644
--- a/server/storage.ts
+++ b/server/storage.ts
@@ -73,13 +73,13 @@ export class DatabaseStorage implements IStorage {
const result = await db.execute(sqlQuery);
console.log(`📊 DatabaseStorage: Found ${result.rows.length} videos (search: "${search || 'none'}")`);
// Transform database rows to Video objects with HLS streaming URLs
return result.rows.map((row: any) => ({
id: row.id,
title: row.title,
description: row.description,
thumbnailUrl: row.thumbnail_url,
- videoUrl: `https://vz-b9208a4c-8c8.b-cdn.net/${row.id}/playlist.m3u8`, // HLS stream URL
+ videoUrl: `https://iframe.mediadelivery.net/embed/384105/${row.id}`, // Original Bunny iframe
duration: row.duration,
views: row.views,
category: row.category,
@@ -110,7 +110,7 @@ export class DatabaseStorage implements IStorage {
title: row.title,
description: row.description,
thumbnailUrl: row.thumbnail_url,
- videoUrl: `https://vz-b9208a4c-8c8.b-cdn.net/${row.id}/playlist.m3u8`, // HLS stream URL
+ videoUrl: `https://iframe.mediadelivery.net/embed/384105/${row.id}`, // Original Bunny iframe
duration: row.duration,
views: row.views,
category: row.category,
@@ -73,13 +73,13 @@ export class DatabaseStorage implements IStorage {
const result = await db.execute(sqlQuery);
console.log(`📊 DatabaseStorage: Found ${result.rows.length} videos (search: "${search || 'none'}")`);
- // Transform database rows to Video objects with HLS streaming URLs
+ // Transform database rows to Video objects with original Bunny iframe URLs
return result.rows.map((row: any) => ({
id: row.id,